@@ -54,6 +54,9 @@ download_geospatial <- function(spatial_level, simplified = TRUE,
   if (simplified) {
     dataset_path <- sub("\\.gpkg$", "_SIM.gpkg", dataset_path)
   }
+
+  message("This might take a while")
+
   geospatial_data <- sf::st_read(dataset_path, quiet = TRUE)
   geospatial_vars <- c("area", "latitud", "longitud")
   shape_vars <- c("shape_length", "shape_area")
@@ -70,10 +73,16 @@ download_geospatial <- function(spatial_level, simplified = TRUE,
   message(strwrap(
     prefix = "\n", initial = "",
     c(
-      "Original data is retrieved from the National Administrative Department of
-      Statistics (Departamento Administrativo Nacional de
-      Estad\u00edstica - DANE).",
-      "Reformatted by package authors.",
+      "ColOpenData provides open data derived from Departamento Administrativo
+      Nacional de Estad\u00edstica (DANE), and Instituto de Hidrolog\u00eda,
+      Meteorolog\u00eda y Estudios Ambientales (IDEAM) but with modifications
+      for specific functional needs. These changes may alter the structure,
+      format, or content, meaning the data does not reflect the official
+      dataset. The package is developed independently, with no endorsement or
+      involvement from these institutions or any Colombian government body. The
+      authors of  ColOpenData are not liable for how users utilize the data,
+      and users areresponsible for any outcomes from their use or analysis of
+      the data.",
       "Stored by Universidad de Los Andes under the Epiverse TRACE iniative."
     )
   ))
